@@ -22,10 +22,10 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'BUILDPYTHON': 'python',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-fno-strict-aliasing -march=armv5te -O2 -pipe -fstack-protector --param=ssp-buffer-size=4 -DNDEBUG -march=armv5te -O2 -pipe -fstack-protector --param=ssp-buffer-size=4',
+ 'CFLAGS': '-fno-strict-aliasing -march=armv5te -O2 -pipe -fstack-protector-strong --param=ssp-buffer-size=4 -DNDEBUG -march=armv5te -O2 -pipe -fstack-protector-strong --param=ssp-buffer-size=4',
  'CFLAGSFORSHARED': '-fPIC',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
- 'CONFIG_ARGS': "'--prefix=/usr' '--enable-shared' '--with-threads' '--enable-ipv6' '--enable-unicode=ucs4' '--with-system-expat' '--with-system-ffi' '--with-dbmliborder=gdbm:ndbm' '--without-ensurepip' 'CFLAGS=-march=armv5te -O2 -pipe -fstack-protector --param=ssp-buffer-size=4' 'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro' 'CPPFLAGS=-D_FORTIFY_SOURCE=2'",
+ 'CONFIG_ARGS': "'--prefix=/usr' '--enable-shared' '--with-threads' '--enable-ipv6' '--enable-unicode=ucs4' '--with-system-expat' '--with-system-ffi' '--with-dbmliborder=gdbm:ndbm' '--without-ensurepip' 'CFLAGS=-march=armv5te -O2 -pipe -fstack-protector-strong --param=ssp-buffer-size=4' 'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro' 'CPPFLAGS=-D_FORTIFY_SOURCE=2'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python2.7',
  'COREPYTHONPATH': ':plat-linux2:lib-tk:lib-old',
@@ -143,7 +143,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETCWD': 1,
  'HAVE_GETC_UNLOCKED': 1,
- 'HAVE_GETENTROPY': 0,
+ 'HAVE_GETENTROPY': 1,
  'HAVE_GETGROUPS': 1,
  'HAVE_GETHOSTBYNAME': 0,
  'HAVE_GETHOSTBYNAME_R': 1,
@@ -356,7 +356,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HGBRANCH': '',
  'HGTAG': '',
  'HGVERSION': '',
- 'HOST_GNU_TYPE': 'armv5tel-unknown-linux-gnueabi',
+ 'HOST_GNU_TYPE': 'armv7l-unknown-linux-gnueabi',
  'HURD_C_THREADS': 0,
  'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python2.7 /usr/include/python2.7',
  'INCLUDEDIR': '/usr/include',
@@ -418,7 +418,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'OPCODETARGETGEN': '\\',
  'OPCODETARGETGEN_FILES': '\\',
  'OPCODETARGETS_H': '\\',
- 'OPT': '-DNDEBUG -march=armv5te -O2 -pipe -fstack-protector --param=ssp-buffer-size=4',
+ 'OPT': '-DNDEBUG -march=armv5te -O2 -pipe -fstack-protector-strong --param=ssp-buffer-size=4',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -454,7 +454,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'PYTHON_FOR_BUILD': './python -E',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_CFLAGS': '-fno-strict-aliasing -march=armv5te -O2 -pipe -fstack-protector --param=ssp-buffer-size=4 -DNDEBUG -march=armv5te -O2 -pipe -fstack-protector --param=ssp-buffer-size=4 -I. -IInclude -I./Include -D_FORTIFY_SOURCE=2 -fPIC -DPy_BUILD_CORE',
+ 'PY_CFLAGS': '-fno-strict-aliasing -march=armv5te -O2 -pipe -fstack-protector-strong --param=ssp-buffer-size=4 -DNDEBUG -march=armv5te -O2 -pipe -fstack-protector-strong --param=ssp-buffer-size=4 -I. -IInclude -I./Include -D_FORTIFY_SOURCE=2 -fPIC -DPy_BUILD_CORE',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_UNICODE_TYPE': 'wchar_t',
@@ -537,9 +537,9 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
  'abs_builddir': '/build/python2/src/Python-2.7.13',
  'abs_srcdir': '/build/python2/src/Python-2.7.13',
- 'build': 'armv5tel-unknown-linux-gnueabi',
+ 'build': 'armv7l-unknown-linux-gnueabi',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
- 'host': 'armv5tel-unknown-linux-gnueabi',
+ 'host': 'armv7l-unknown-linux-gnueabi',
  'prefix': '/usr',
  'srcdir': '.'}
